package sun.security.util;

import java.io.IOException;
import java.math.BigInteger;
import java.security.spec.ECPoint;
import java.security.spec.EllipticCurve;
import java.security.spec.ECParameterSpec;

public class NamedCurve extends ECParameterSpec
{
    private final String name;
    private final String oid;
    private final byte[] encoded;
    
    NamedCurve(String name, String oid, EllipticCurve curve, ECPoint g, BigInteger n, int h) {
        super(curve, g, n, h);
        this.name = name;
        this.oid = oid;
        DerOutputStream derOutputStream = new DerOutputStream();
        try {
            derOutputStream.putOID(new ObjectIdentifier(oid));
        }
        catch (IOException cause) {
            throw new RuntimeException("Internal error", cause);
        }
        this.encoded = derOutputStream.toByteArray();
    }
    
    public String getName() {
        return this.name;
    }
    
    byte[] getEncoded() {
        return (byte[])this.encoded.clone();
    }
    
    public String getObjectId() {
        return this.oid;
    }
    
    @Override
    public String toString() {
        return this.name + " (" + this.oid + ")";
    }
}
